Reshape Map
===========

Builds or modifies the shape of the input dataset to create 2D maps from series data or change the dimensions of existing 2D datasets.

**Inputs**

- Data: input dataset

**Outputs**

- Map Data: data as a map

The **Reshape Map** widget transforms the input data to a map.

![](images/Reshape-Map-stamped.png)

1. Map shape:
   - The X dimension.
   - The Y dimension.
2. Send data automatically or press *Send*.
